bayespy.inference.vmp.transformations.RotateSwitchingMarkovChain.get_bound_terms
================================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateSwitchingMarkovChain.get_bound_terms